Documentation
¶
Index ¶
- func DeriveSeedFromMnemonic(mnemonic string) string
- func MnemonicPhraseChineaseSimplified(i []int, e error) ([]string, error)
- func MnemonicPhraseChineaseTraditional(i []int, e error) ([]string, error)
- func MnemonicPhraseEnglish(i []int, e error) ([]string, error)
- func MnemonicPhraseForLanguage(i []int, l wordlists.BIP39Wordlist) ([]string, error)
- func MnemonicPhraseFrench(i []int, e error) ([]string, error)
- func MnemonicPhraseItalian(i []int, e error) ([]string, error)
- func MnemonicPhraseJapanese(i []int, e error) ([]string, error)
- func MnemonicPhraseKorean(i []int, e error) ([]string, error)
- func MnemonicPhraseSpanish(i []int, e error) ([]string, error)
- func New12WordEntropy() ([]int, error)
- func New15WordEntropy() ([]int, error)
- func New18WordEntropy() ([]int, error)
- func New21WordEntropy() ([]int, error)
- func New24WordEntropy() ([]int, error)
- func New24WordMnemonicPhraseForLanguage(language string) (string, error)
- func NewWordEntropy(l lengths.SeedBitLength) ([]int, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeriveSeedFromMnemonic ¶
DeriveSeedFromMnemonic is a GoMobile compatible function that returns the hex encoded seed derived from the given mnemonic
func MnemonicPhraseChineaseSimplified ¶
MnemonicPhraseChineaseSimplified uses given entropy to return a mnemonic phrase for the Chinease Simplified language
func MnemonicPhraseChineaseTraditional ¶
MnemonicPhraseChineaseTraditional uses given entropy to return a mnemonic phrase for the Chinease Traditional language
func MnemonicPhraseEnglish ¶
MnemonicPhraseEnglish uses given entropy to return a mnemonic phrase for the English language
func MnemonicPhraseForLanguage ¶
func MnemonicPhraseForLanguage(i []int, l wordlists.BIP39Wordlist) ([]string, error)
MnemonicPhraseForLanguage uses given entropy and language to generate a mnemonic phrase
func MnemonicPhraseFrench ¶
MnemonicPhraseFrench uses given entropy to return a mnemonic phrase for the French language
func MnemonicPhraseItalian ¶
MnemonicPhraseItalian uses given entropy to return a mnemonic phrase for the Italian language
func MnemonicPhraseJapanese ¶
MnemonicPhraseJapanese uses given entropy to return a mnemonic phrase for the Japanese language
func MnemonicPhraseKorean ¶
MnemonicPhraseKorean uses given entropy to return a mnemonic phrase for the Korean language
func MnemonicPhraseSpanish ¶
MnemonicPhraseSpanish uses given entropy to return a mnemonic phrase for the Spanish language
func New12WordEntropy ¶
New12WordEntropy returns new twelve length seed as an integer slice
func New15WordEntropy ¶
New15WordEntropy returns new fiveteen length seed as an integer slice
func New18WordEntropy ¶
New18WordEntropy returns new eighteen length seed as an integer slice
func New21WordEntropy ¶
New21WordEntropy returns new twentyone length seed as an integer slice
func New24WordEntropy ¶
New24WordEntropy returns new twentyfour length seed as an integer slice
func New24WordMnemonicPhraseForLanguage ¶
New24WordMnemonicPhraseForLanguage is a GoMobile compatible function that returns a new random 24 word mnemonic phrase for given language as a single space seperated string
func NewWordEntropy ¶
func NewWordEntropy(l lengths.SeedBitLength) ([]int, error)
NewWordEntropy returns new mnemonic integer slice of given length
Types ¶
This section is empty.